@@ -39,6 +39,24 @@ Sjis-JA - Source code filter to escape ShiftJIS (Japanese document)
         Sjis::index(...);
         Sjis::rindex(...);
 
+      Perl5.6 G~[V֐
+        binmode(...);
+        open(...);
+
+      ȉ̓_~[֐Ƃ
+        utf8::upgrade(...);
+        utf8::downgrade(...);
+        utf8::encode(...);
+        utf8::decode(...);
+        utf8::is_utf8(...);
+        utf8::valid(...);
+        bytes::chr(...);
+        bytes::index(...);
+        bytes::length(...);
+        bytes::ord(...);
+        bytes::rindex(...);
+        bytes::substr(...);
+
    g: B
 
     R}hvvgňȉ̂悤Ɏs
@@ -315,6 +333,21 @@ Esjis::* ֐ Esjis.pm 񋟂܂B
   no Perl::Module ();      BEGIN { Esjis::require 'Perl/Module.pm'; }
   ------------------------------------------------------------------------------------------------------------------------
 
+=head1 bytes::* ֐̃AGXP[v
+
+̃\tgEFAɂ bytes::* ֐̐擪 'bytes::' 菜܂B
+
+  ------------------------------------
+  O           
+  ------------------------------------
+  bytes::chr       chr
+  bytes::index     index
+  bytes::length    length
+  bytes::ord       ord
+  bytes::rindex    rindex
+  bytes::substr    substr
+  ------------------------------------
+
 =head1 t@CeXgZq̃GXP[v
 
 ̃\tgEFAɂĉZq '-'  'Esjis::' ɏ܂B
@@ -433,13 +466,11 @@ WW[̃t@C /Perl/site/lib/Sjis ɃRs[ 'use utf8;'
 
     ̒APʂł͂ȂAoCgPʂŐɂ
 
-    $blen = length $string;
+    $blen = length($string);
+    $blen = CORE::length($string);
+    $blen = bytes::length($string);
 
-    邢
-
-    $blen = CORE::length $string;
-
-    Ƃ܂B
+    ̂ꂩg܂B
 
 =item * Sjis::substr
 
@@ -515,6 +546,208 @@ WW[̃t@C /Perl/site/lib/Sjis ɃRs[ 'use utf8;'
 
 =back
 
+=head1 perl5.005 ɂ Perl5.6 G~[V
+
+  perl5.005 𗘗pĂۂ Perl5.6 ̊֐̓G~[g܂B
+
+  --------------------------------------------------------------------
+  O                           Esjis.pm  BEGIN { } Őݒ
+  --------------------------------------------------------------------
+  binmode(...);   Esjis::binmode(...);   *CORE::GLOBAL::binmode = ...
+  open(...);      Esjis::open(...);      *CORE::GLOBAL::open    = ...
+  --------------------------------------------------------------------
+
+=head1  utf8 vO}
+
+  utf8 vO}Abytes vO}̓RgAEg܂Bt@CŒ񋟂
+  ֐̑Ƃ Esjis.pm _~[֐񋟂܂B
+
+  ---------------------------------------------------------------------
+  O                           
+  ---------------------------------------------------------------------
+  use utf8;       # use utf8;            Esjis.pm  no utf8; Ă
+  no utf8;        # no utf8;             Ƃ utf8::* ֐񋟂܂
+  use bytes;      # use bytes;           Esjis.pm  no bytes; Ă
+  no bytes;       # no bytes;            Ƃ bytes::* ֐񋟂܂
+  ---------------------------------------------------------------------
+
+=over 2
+
+=item binmode (perl5.005 ɂ Perl5.6 G~[V)
+
+  binmode(FILEHANDLE, $disciplines);
+  binmode(FILEHANDLE);
+  binmode($filehandle, $disciplines);
+  binmode($filehandle);
+
+  * 2 ̈g܂
+
+  perl5.005 Ŏsꍇ́APerl5.6  binmode ֐̋@\G~[g܂B
+  ȉ͗v_݂̂̋LqȂ̂ŁAڍׂ perlfunc/binmode QƂĂB
+
+   t@Cnh FILEHANDLE ɑ΂āA$disciplines Ŏw肳ꂽs
+  ɂB$disciplines ȗƁAt@Cnh ':raw' ƂĈ悤
+  BFILEHANDLE ꍇA̒lt@Cnh̖O܂̓t@Cn
+  hւ̃t@XƂĈB
+
+   binmode ֐́At@C open ĂÃt@Cnhɑ΂Ďۂ I/O
+  s܂ł̊ԂɁAsȂ΂ȂȂB܂܂ȃ[hAobt@̂
+  ܂܂ȃf[^ɑ΂āA܂܂ȉHs߂ɁAt@C̃[hZbg
+  ɂ́Ãt@CI[vȂȊOɕ@͂ȂB
+
+   ":raw" fBVv́APerl f[^̒gɎoȂ悤ɂ邽߂̂̂ł
+  BefBVvǂ̂悤ɓ삷邩ɂĂ open ֐̍QƂĂ
+  B
+
+=item open (perl5.005 ɂ Perl5.6 G~[V)
+
+  open(FILEHANDLE, $mode, @list);
+  open(FILEHANDLE, $expr);
+  open(FILEHANDLE);
+  open(my $filehandle, $mode, @list);
+  open(my $filehandle, $expr);
+  open(my $filehandle);
+
+  * t@Cnh(autovivification)܂
+  * 3 ̈g܂
+
+  perl5.005 Ŏsꍇ́APerl5.6  open ֐̋@\G~[g܂B
+  ȉ͗v_݂̂̋LqȂ̂ŁAڍׂ perlfunc/open QƂĂB
+
+   ̗Ⴊ悤ɁAĂ̏ꍇAFILEHANDLE ͒PȎʎq(ʂ͑啶
+  ݂̂琬)ł邪A̒lt@Cnhւ̃t@XɂȂ悤Ȏ
+  w肷邱ƂłB(̃t@Xɂ́At@Cnhɑ΂V{
+  bNt@XA܂̓t@CnhƉ߂łCӂ̃IuWFNgւ
+  n[ht@XwłB)͊Ԑڃt@Cnh(indirect filehandle)
+  ƌĂ΂B1Ƃ FILEHANDLE 󂯎邷ׂĂ̊֐́At@Cnh
+  ̑ɁAԐڃt@Cnh󂯎邱ƂłB open ̏ꍇ͓
+  ŁAԐڃt@CnhƂĖ`̕ϐw肷ƁAPerl ͎Iɂ̕ϐ
+  `āAɂāAK؂ȃt@Cnhւ̃t@XZbg
+  B̗_1ƂẮAt@CnhǂQƂȂȂ(T^
+  Iɂ́A̕ϐ̃XR[v甲oꍇ)ƁAIɃN[YƂ
+  B
+
+  {
+      my $fh;                   # (ĂȂ)
+      open($fh, ">logfile")     # $fh ͎
+          or die "Can't create logfile: $!";
+          ...                   # $fh gďs
+  }                             # $fh ͂ŃN[Y
+
+  ܂Â悤ɂāAopen ֐Ăяoۂ my $fh 錾s΁Aɓǂ݂₷
+  Ȃ:
+
+  open my $fh, ">logfile" or die ...
+
+   ŁAt@C̐擪ɂ ">" ́A[ḧłBjIȘbƁA
+  ɗpӂꂽ open 2̂̂łBŋ߁Aꂽ3 open ł́A[
+  ht@CƗĕʌɎwł̂ŁA炪邱ƂȂƂ
+  _BႦ΁AɎR[hł́A">" Ŏn܂閼Ot@CI[v
+  킯ł͂ȂƂ킩B̃R[hł́A$mode Ƃ ">" w肳Ă
+  ŁA$expr Ŏw肳ꂽOt@CݗpɃI[v悤ƂB
+  ̍ۂɁAt@C݂ȂΐVɍ쐬AłɃt@C݂΁A
+  ̃t@C؂̂Ăċɂ:
+  
+  open(LOG, ">", "logfile")  or die "Can't create logfile: $!";
+
+   12 open ł́Aϐt@CƂĎgۂɂ͒ӂKvłB
+  ȂȂAϐ͓̂̒mȂ镶܂ł\邩炾(ɁAC
+  ^[lbg̓̂̒mȂ[Ut@C󂯎ꍇ)B\ɒӂȂ
+  ƁAt@C̈ꕔA$mode A󔒕Adup wq(>& Ȃ)A
+  }CiX "-" Ɖ߂Ă܂\BɎ̂́Ãgu邽
+  ߂ɁA`IɍsĂ1łB
+
+  $path =~ s#^([ ])#./$1#;
+  open (FH, "< $path\0") or die "can't open $path: $!";
+
+   Aɂ܂肪BɁA3 open g悤ɂ
+  ΁AZLeB̃XNɂ炳ꂸɁACӂ̃t@CAN[Ɉ
+  ł:
+
+  open(FH, "<", $path) or die "can't open $path: $!";
+
+   ܂APerl ̃[X 5.6 ł́Aopen ֐ŃoCi[hwł悤ɂȂ
+  Ă̂ŁA킴킴 binmode ֐ʂɌĂяoɍςށB$mode ̈ꕔƂāA
+  X̓̓fBVvƏo̓fBVvw肷邱Ƃł(3̏ꍇ̂)B
+  binmode ƓȂƂɂ́A3 open gāA $mode ̌
+  :raw fBVvw肷΂悢:
+
+  open(FH, "<:raw", $path) or die "can't open $path: $!";
+
+  \ 1. I/O fBVv
+  -------------------------------------------------
+  fBVv    Ӗ
+  -------------------------------------------------
+  :raw            oCi[hAȂ
+  :crlf           s𔻕ʂ
+  :encoding(...)  GR[fBOw肷
+  -------------------------------------------------
+
+   (邱ƂɈӖȂ)fBVvςݏd˂邱ƂłBႦ΁A
+  ̂悤Ȏw\ł:
+
+  open(FH, "<:crlf:encoding(Sjis)", $path) or die "can't open $path: $!";
+
+=item _~[̊֐ utf8::upgrade
+
+  $num_octets = utf8::upgrade($string);
+
+  $string ̃INebgԂ܂B
+
+=item _~[̊֐ utf8::downgrade
+
+  $success = utf8::downgrade($string[, FAIL_OK]);
+
+  ̊֐͏ɐ^̒lԂ܂B
+
+=item _~[̊֐ utf8::encode
+
+  utf8::encode($string);
+
+  ̊֐͉Ԃ܂B
+
+=item _~[̊֐ utf8::decode
+
+  $success = utf8::decode($string);
+
+  ̊֐͏ɐ^̒lԂ܂B
+
+=item _~[̊֐ utf8::is_utf8
+
+  $flag = utf8::is_utf8(STRING);
+
+  ̊֐͏ɋU̒lԂ܂B
+
+=item _~[̊֐ utf8::valid
+
+  $flag = utf8::valid(STRING);
+
+  ̊֐͏ɐ^̒lԂ܂B
+
+=item _~[̊֐ bytes::chr
+
+  oCgẘ֐ chr ƂĎĂ܂B
+
+=item _~[̊֐ bytes::index
+
+  oCgẘ֐ index ƂĎĂ܂B
+
+=item _~[̊֐ bytes::length
+
+  oCgẘ֐ length ƂĎĂ܂B
+
+=item _~[̊֐ bytes::ord
+
+  oCgẘ֐ ord ƂĎĂ܂B
+
+=item _~[̊֐ bytes::rindex
+
+  oCgẘ֐ rindex ƂĎĂ܂B
+
+=item _~[̊֐ bytes::substr
+
+  oCgẘ֐ substr ƂĎĂ܂B
+
 =head1 ϐ
 
  ̃\tgEFA͔r flock ֐gp܂Bt@Cǎ\ɂȂ܂
@@ -538,12 +771,6 @@ oO񍐁Apb`}܂B
 
     IWi Perl Ƌ@\ł(ShiftJIS ɑΉĂ܂)B
 
-=item * m/$re/o, s/$re/foo/o, qr/$re/o  /o Cq
-
-    perl5.006 ɂ /o CqҒʂ̓܂łBϐ $re ̒l
-    ύXƎ̎sɂ̕ύXf܂Bł /o gƂ $re
-    ̓eύXȂł傤AۂɖɂȂ邱Ƃ͂Ȃł傤B
-
 =item * chdir
 
     MSWin32  perl5.006, perl5.008, perl5.010, perl5.012 ɂĕR[h(0x5C)
@@ -1459,6 +1686,7 @@ vO~O񋟂܂B
 
   e, Encode W[
  http://search.cpan.org/dist/Encode/
+ http://www.dan.co.jp/~dankogai/yapcasia2006/slide.html
 
  Juerd, Perl Unicode Advice
  http://juerd.nl/site.plp/perluniadvice
@@ -1474,7 +1702,7 @@ vO~O񋟂܂B
  http://mail.pm.org/pipermail/tokyo-pm/1999-September/001844.html
  http://mail.pm.org/pipermail/tokyo-pm/1999-September/001854.html
 
- ruby-list
+ ruby-list (݂ 404 Not Found ɂȂĂ܂)
  http://blade.nagaokaut.ac.jp/ruby/ruby-list/index.shtml
  http://blade.nagaokaut.ac.jp/cgi-bin/scat.rb/ruby/ruby-list/2440
  http://blade.nagaokaut.ac.jp/cgi-bin/scat.rb/ruby/ruby-list/2446
